@@ -44,6 +44,7 @@
 
 #include "getopt.h"
 #include "fetchmail.h"
+#include "socket.h"
 #include "tunable.h"
 #include "smtp.h"
 #include "netrc.h"
@@ -482,10 +483,11 @@ int main(int argc, char **argv)
 		&& ctl->server.protocol != P_IMAP_GSS
 #endif /* GSSAPI */
 		&& !ctl->password)
+	{
 	    if (!isatty(0))
 	    {
 		fprintf(stderr,
-			_("fetchmail: can't find a password for %s@s.\n"),
+			_("fetchmail: can't find a password for %s@%s.\n"),
 			ctl->remotename, ctl->server.pollname);
 		return(PS_AUTHFAIL);
 	    }
@@ -500,6 +502,7 @@ int main(int argc, char **argv)
 			       ctl->remotename, ctl->server.pollname);
 		ctl->password = xstrdup((char *)fm_getpassword(tmpbuf));
 	    }
+	}
     }
 
     /*
@@ -645,8 +648,9 @@ int main(int argc, char **argv)
 		querystatus = query_host(ctl);
 
 #ifdef POP3_ENABLE
-		if (!check_only)
-		    uid_end_query(ctl);
+		/* leave the UIDL state alone if there have been any errors */
+		if (!check_only && !querystatus)
+		    uid_swap_lists(ctl);
 #endif  /* POP3_ENABLE */
 
 		if (querystatus == PS_SUCCESS)
@@ -922,7 +926,7 @@ static int load_params(int argc, char **argv, int optind)
 			|| str_in_list(&ctl->server.akalist, argv[optind], TRUE))
 		{
 		    /* Is this correct? */
-		    if(predeclared)
+		    if (predeclared && outlevel == O_VERBOSE)
 			fprintf(stderr,_("Warning: multiple mentions of host %s in config file\n"),argv[optind]);
 		    ctl->active = TRUE;
 		    predeclared = TRUE;
@@ -1175,8 +1179,9 @@ static int load_params(int argc, char **argv, int optind)
 		       namerec->h_addr_list[0],
 		       namerec->h_length);
 	      }
-#endif /* HAVE_GETHOSTBYNAME */
+#else
 	      ctl->server.truename = xstrdup(ctl->server.queryname);
+#endif /* HAVE_GETHOSTBYNAME */
 	    }
 
 	    /* if no folders were specified, set up the null one as default */
