@@ -344,10 +344,10 @@ va_dcl {
 }
 
 #ifdef SSL_ENABLE
-#include "ssl.h"
-#include "err.h"
-#include "pem.h"
-#include "x509.h"
+#include "openssl/ssl.h"
+#include "openssl/err.h"
+#include "openssl/pem.h"
+#include "openssl/x509.h"
 
 static	SSL_CTX *_ctx = NULL;
 static	SSL *_ssl_context[FD_SETSIZE];
@@ -602,7 +602,7 @@ int SSL_verify_callback( int ok_return, X509_STORE_CTX *ctx )
 				report(stdout, "Server CommonName: %s\n", cbuf );
 			/* Should we have some wildcarding here? */
 			if ( NULL != _ssl_server_cname
-			     && 0 != strcmp( cbuf, _ssl_server_cname ) ) {
+			     && 0 != strcasecmp( cbuf, _ssl_server_cname ) ) {
 				report(stdout,
 				       "Server CommonName mismatch: %s != %s\n",
 				       cbuf, _ssl_server_cname );
@@ -698,7 +698,6 @@ int SSLOpen(int sock, char *mycert, char *mykey, char *servercname )
 int SockClose(int sock)
 /* close a socket gracefully */
 {
-    char ch;
 #ifdef	SSL_ENABLE
     SSL *ssl;
 
@@ -721,6 +720,7 @@ int SockClose(int sock)
      * This stops sends but allows receives (effectively, it sends a
      * TCP <FIN>).  */
     if (shutdown(sock, 1) == 0) {
+	char ch;
 	/* If there is any data still waiting in the queue, discard it.
 	 * Call recv() until either it returns 0 (meaning we received a FIN)
 	 * or any error occurs.  This makes sure all data sent by the other
