@@ -58,4 +58,8 @@ additional clean-up if necessary.
 */
 int SockClose(int sock);
 
+#if SSL_ENABLE
+int SSLOpen(int sock, char *mycert, char *mykey, char *servercname);
+#endif /* SSL_ENABLE */
+
 #endif /* SOCKET__ */
